@@ -57,7 +57,7 @@ def check_node_info(node_info):
 
     return True
 
-def apply(squadron_dir, node_name, tempdir, dry_run=False):
+def apply(squadron_dir, node_name, tempdir, resources, dry_run=False):
     """
     This method takes input from the given squadron_dir and configures
     a temporary directory according to that information
@@ -121,7 +121,7 @@ def apply(squadron_dir, node_name, tempdir, dry_run=False):
 
         tmp_serv_dir = os.path.join(tempdir, service)
         makedirsp(tmp_serv_dir)
-        atomic = render.render(tmp_serv_dir, cfg, dry_run)
+        atomic = render.render(tmp_serv_dir, cfg, resources, dry_run)
 
         result[service] = {
                 'atomic': atomic,
